@@ -56,55 +56,79 @@ lsm_c_circle_cv <- function(landscape, directions) UseMethod("lsm_c_circle_cv")
 #' @name lsm_c_circle_cv
 #' @export
 lsm_c_circle_cv.RasterLayer <- function(landscape, directions = 8) {
-    purrr::map_dfr(raster::as.list(landscape),
-                   lsm_c_circle_cv_calc,
-                   directions = directions, .id = "layer") %>%
-        dplyr::mutate(layer = as.integer(layer))
+
+    result <- lapply(X = raster::as.list(landscape),
+                     FUN = lsm_c_circle_cv_calc,
+                     directions = directions)
+
+    dplyr::mutate(dplyr::bind_rows(result, .id = "layer"),
+                  layer = as.integer(layer))
 }
 
 #' @name lsm_c_circle_cv
 #' @export
 lsm_c_circle_cv.RasterStack <- function(landscape, directions = 8) {
-    purrr::map_dfr(raster::as.list(landscape),
-                   lsm_c_circle_cv_calc,
-                   directions = directions, .id = "layer") %>%
-        dplyr::mutate(layer = as.integer(layer))
 
+    result <- lapply(X = raster::as.list(landscape),
+                     FUN = lsm_c_circle_cv_calc,
+                     directions = directions)
+
+    dplyr::mutate(dplyr::bind_rows(result, .id = "layer"),
+                  layer = as.integer(layer))
 }
 
 #' @name lsm_c_circle_cv
 #' @export
 lsm_c_circle_cv.RasterBrick <- function(landscape, directions = 8) {
-    purrr::map_dfr(raster::as.list(landscape),
-                   lsm_c_circle_cv_calc,
-                   directions = directions, .id = "layer") %>%
-        dplyr::mutate(layer = as.integer(layer))
 
+    result <- lapply(X = raster::as.list(landscape),
+                     FUN = lsm_c_circle_cv_calc,
+                     directions = directions)
+
+    dplyr::mutate(dplyr::bind_rows(result, .id = "layer"),
+                  layer = as.integer(layer))
 }
 
 #' @name lsm_c_circle_cv
 #' @export
-lsm_c_circle_cv.list <- function(landscape, directions = 8) {
-    purrr::map_dfr(landscape, lsm_c_circle_cv_calc,
-                   directions = directions, .id = "layer") %>%
-        dplyr::mutate(layer = as.integer(layer))
+lsm_c_circle_cv.stars <- function(landscape, directions = 8) {
 
+    landscape <- methods::as(landscape, "Raster")
+
+    result <- lapply(X = raster::as.list(landscape),
+                     FUN = lsm_c_circle_cv_calc,
+                     directions = directions)
+
+    dplyr::mutate(dplyr::bind_rows(result, .id = "layer"),
+                  layer = as.integer(layer))
+}
+
+
+#' @name lsm_c_circle_cv
+#' @export
+lsm_c_circle_cv.list <- function(landscape, directions = 8) {
+
+    result <- lapply(X = landscape,
+                     FUN = lsm_c_circle_cv_calc,
+                     directions = directions)
+
+    dplyr::mutate(dplyr::bind_rows(result, .id = "layer"),
+                  layer = as.integer(layer))
 }
 
 lsm_c_circle_cv_calc <- function(landscape, directions) {
 
-    circle_mn  <- landscape %>%
-        lsm_p_circle_calc(., directions = directions) %>%
-        dplyr::group_by(class)  %>%
-        dplyr::summarize(value = raster::cv(value))
+    circle <- lsm_p_circle_calc(landscape, directions = directions)
+
+    circle_cv <-  dplyr::summarize(dplyr::group_by(circle, class),
+                                   value = raster::cv(value))
 
     tibble::tibble(
         level = "class",
-        class = as.integer(circle_mn$class),
+        class = as.integer(circle_cv$class),
         id = as.integer(NA),
         metric = "circle_cv",
-        value = as.double(circle_mn$value)
+        value = as.double(circle_cv$value)
     )
-
 }
 
