@@ -48,41 +48,63 @@ lsm_c_division <- function(landscape, directions) UseMethod("lsm_c_division")
 #' @name lsm_c_division
 #' @export
 lsm_c_division.RasterLayer <- function(landscape, directions = 8) {
-    purrr::map_dfr(raster::as.list(landscape),
-                   lsm_c_division_calc,
-                   directions = directions,
-                   .id = "layer") %>%
-        dplyr::mutate(layer = as.integer(layer))
+
+    result <- lapply(X = raster::as.list(landscape),
+                     FUN = lsm_c_division_calc,
+                     directions = directions)
+
+    dplyr::mutate(dplyr::bind_rows(result, .id = "layer"),
+                  layer = as.integer(layer))
 }
 
 #' @name lsm_c_division
 #' @export
 lsm_c_division.RasterStack <- function(landscape, directions = 8) {
-    purrr::map_dfr(raster::as.list(landscape),
-                   lsm_c_division_calc,
-                   directions = directions,
-                   .id = "layer") %>%
-        dplyr::mutate(layer = as.integer(layer))
+
+    result <- lapply(X = raster::as.list(landscape),
+                     FUN = lsm_c_division_calc,
+                     directions = directions)
+
+    dplyr::mutate(dplyr::bind_rows(result, .id = "layer"),
+                  layer = as.integer(layer))
 }
 
 #' @name lsm_c_division
 #' @export
 lsm_c_division.RasterBrick <- function(landscape, directions = 8) {
-    purrr::map_dfr(raster::as.list(landscape),
-                   lsm_c_division_calc,
-                   directions = directions,
-                   .id = "layer") %>%
-        dplyr::mutate(layer = as.integer(layer))
+
+    result <- lapply(X = raster::as.list(landscape),
+                     FUN = lsm_c_division_calc,
+                     directions = directions)
+
+    dplyr::mutate(dplyr::bind_rows(result, .id = "layer"),
+                  layer = as.integer(layer))
+}
+
+#' @name lsm_c_area_sd
+#' @export
+lsm_c_division.stars <- function(landscape, directions = 8) {
+
+    landscape <- methods::as(landscape, "Raster")
+
+    result <- lapply(X = raster::as.list(landscape),
+                     FUN = lsm_c_division_calc,
+                     directions = directions)
+
+    dplyr::mutate(dplyr::bind_rows(result, .id = "layer"),
+                  layer = as.integer(layer))
 }
 
 #' @name lsm_c_division
 #' @export
 lsm_c_division.list <- function(landscape, directions = 8) {
-    purrr::map_dfr(landscape,
-                   lsm_c_division_calc,
-                   directions = directions,
-                   .id = "layer") %>%
-        dplyr::mutate(layer = as.integer(layer))
+
+    result <- lapply(X = landscape,
+                     FUN = lsm_c_division_calc,
+                     directions = directions)
+
+    dplyr::mutate(dplyr::bind_rows(result, .id = "layer"),
+                  layer = as.integer(layer))
 }
 
 lsm_c_division_calc <- function(landscape, directions) {
@@ -92,10 +114,11 @@ lsm_c_division_calc <- function(landscape, directions) {
     area_patch <- lsm_p_area_calc(landscape, directions = directions)
 
     division <- dplyr::mutate(area_patch,
-                              value = (value / area_landscape$value) ^ 2) %>%
-        dplyr::group_by(class) %>%
-        dplyr::summarise(value = sum(value)) %>%
-        dplyr::mutate(value = 1 - value)
+                              value = (value / area_landscape$value) ^ 2)
+
+    division <-  dplyr::mutate(dplyr::summarise(dplyr::group_by(division, class),
+                                 value = sum(value)),
+                               value = 1 - value)
 
     tibble::tibble(
         level = "class",
