@@ -54,52 +54,71 @@ lsm_c_frac_cv <- function(landscape, directions) UseMethod("lsm_c_frac_cv")
 #' @name lsm_c_frac_cv
 #' @export
 lsm_c_frac_cv.RasterLayer <- function(landscape, directions = 8) {
-    purrr::map_dfr(raster::as.list(landscape),
-                   lsm_c_frac_cv_calc,
-                   directions = directions,
-                   .id = "layer") %>%
-        dplyr::mutate(layer = as.integer(layer))
+
+    result <- lapply(X = raster::as.list(landscape),
+                     FUN = lsm_c_frac_cv_calc,
+                     directions = directions)
+
+    dplyr::mutate(dplyr::bind_rows(result, .id = "layer"),
+                  layer = as.integer(layer))
 }
 
 #' @name lsm_c_frac_cv
 #' @export
 lsm_c_frac_cv.RasterStack <- function(landscape, directions = 8) {
-    purrr::map_dfr(raster::as.list(landscape),
-                   lsm_c_frac_cv_calc,
-                   directions = directions,
-                   .id = "layer") %>%
-        dplyr::mutate(layer = as.integer(layer))
 
+    result <- lapply(X = raster::as.list(landscape),
+                     FUN = lsm_c_frac_cv_calc,
+                     directions = directions)
+
+    dplyr::mutate(dplyr::bind_rows(result, .id = "layer"),
+                  layer = as.integer(layer))
 }
 
 #' @name lsm_c_frac_cv
 #' @export
 lsm_c_frac_cv.RasterBrick <- function(landscape, directions = 8) {
-    purrr::map_dfr(raster::as.list(landscape),
-                   lsm_c_frac_cv_calc,
-                   directions = directions,
-                   .id = "layer") %>%
-        dplyr::mutate(layer = as.integer(layer))
 
+    result <- lapply(X = raster::as.list(landscape),
+                     FUN = lsm_c_frac_cv_calc,
+                     directions = directions)
+
+    dplyr::mutate(dplyr::bind_rows(result, .id = "layer"),
+                  layer = as.integer(layer))
+}
+
+#' @name lsm_c_frac_cv
+#' @export
+lsm_c_frac_cv.stars <- function(landscape, directions = 8) {
+
+    landscape <- methods::as(landscape, "Raster")
+
+    result <- lapply(X = raster::as.list(landscape),
+                     FUN = lsm_c_frac_cv_calc,
+                     directions = directions)
+
+    dplyr::mutate(dplyr::bind_rows(result, .id = "layer"),
+                  layer = as.integer(layer))
 }
 
 #' @name lsm_c_frac_cv
 #' @export
 lsm_c_frac_cv.list <- function(landscape, directions = 8) {
-    purrr::map_dfr(landscape,
-                   lsm_c_frac_cv_calc,
-                   directions = directions,
-                   .id = "layer") %>%
-        dplyr::mutate(layer = as.integer(layer))
 
+    result <- lapply(X = landscape,
+                     FUN = lsm_c_frac_cv_calc,
+                     directions = directions)
+
+    dplyr::mutate(dplyr::bind_rows(result, .id = "layer"),
+                  layer = as.integer(layer))
 }
 
 lsm_c_frac_cv_calc <- function(landscape, directions){
 
-    frac_cv <- landscape %>%
-        lsm_p_frac_calc(directions = directions) %>%
-        dplyr::group_by(class) %>%
-        dplyr::summarise(value = raster::cv(value))
+    frac <- lsm_p_frac_calc(landscape, directions = directions)
+
+    frac_cv <- dplyr::summarise(dplyr::group_by(frac, class),
+                                value = raster::cv(value))
 
     tibble::tibble(
         level = "class",
