@@ -48,41 +48,63 @@ lsm_l_division <- function(landscape, directions) UseMethod("lsm_l_division")
 #' @name lsm_l_division
 #' @export
 lsm_l_division.RasterLayer <- function(landscape, directions = 8) {
-    purrr::map_dfr(raster::as.list(landscape),
-                   lsm_l_division_calc,
-                   directions = directions,
-                   .id = "layer") %>%
-        dplyr::mutate(layer = as.integer(layer))
+
+    result <- lapply(X = raster::as.list(landscape),
+                     FUN = lsm_l_division_calc,
+                     directions = directions)
+
+    dplyr::mutate(dplyr::bind_rows(result, .id = "layer"),
+                  layer = as.integer(layer))
 }
 
 #' @name lsm_l_division
 #' @export
 lsm_l_division.RasterStack <- function(landscape, directions = 8) {
-    purrr::map_dfr(raster::as.list(landscape),
-                   lsm_l_division_calc,
-                   directions = directions,
-                   .id = "layer") %>%
-        dplyr::mutate(layer = as.integer(layer))
+
+    result <- lapply(X = raster::as.list(landscape),
+                     FUN = lsm_l_division_calc,
+                     directions = directions)
+
+    dplyr::mutate(dplyr::bind_rows(result, .id = "layer"),
+                  layer = as.integer(layer))
 }
 
 #' @name lsm_l_division
 #' @export
 lsm_l_division.RasterBrick <- function(landscape, directions = 8) {
-    purrr::map_dfr(raster::as.list(landscape),
-                   lsm_l_division_calc,
-                   directions = directions,
-                   .id = "layer") %>%
-        dplyr::mutate(layer = as.integer(layer))
+
+    result <- lapply(X = raster::as.list(landscape),
+                     FUN = lsm_l_division_calc,
+                     directions = directions)
+
+    dplyr::mutate(dplyr::bind_rows(result, .id = "layer"),
+                  layer = as.integer(layer))
+}
+
+#' @name lsm_l_division
+#' @export
+lsm_l_division.stars <- function(landscape, directions = 8) {
+
+    landscape <- methods::as(landscape, "Raster")
+
+    result <- lapply(X = raster::as.list(landscape),
+                     FUN = lsm_l_division_calc,
+                     directions = directions)
+
+    dplyr::mutate(dplyr::bind_rows(result, .id = "layer"),
+                  layer = as.integer(layer))
 }
 
 #' @name lsm_l_division
 #' @export
 lsm_l_division.list <- function(landscape, directions = 8) {
-    purrr::map_dfr(landscape,
-                   lsm_l_division_calc,
-                   directions = directions,
-                   .id = "layer") %>%
-        dplyr::mutate(layer = as.integer(layer))
+
+    result <- lapply(X = landscape,
+                     FUN = lsm_l_division_calc,
+                     directions = directions)
+
+    dplyr::mutate(dplyr::bind_rows(result, .id = "layer"),
+                  layer = as.integer(layer))
 }
 
 lsm_l_division_calc <- function(landscape, directions) {
@@ -91,10 +113,10 @@ lsm_l_division_calc <- function(landscape, directions) {
 
     area_patch <- lsm_p_area_calc(landscape, directions = directions)
 
-    division <- area_patch %>%
-        dplyr::mutate(value = (value / area_landscape$value) ^ 2) %>%
-        dplyr::summarise(value = sum(value)) %>%
-        dplyr::mutate(value = 1 - value)
+    division <- dplyr::mutate(area_patch, value = (value / area_landscape$value) ^ 2)
+
+    division <- dplyr::mutate(dplyr::summarise(division, value = sum(value)),
+                              value = 1 - value)
 
     tibble::tibble(
         level = "landscape",
