@@ -56,55 +56,75 @@ lsm_l_enn_sd <- function(landscape, directions, verbose) UseMethod("lsm_l_enn_sd
 #' @name lsm_l_enn_sd
 #' @export
 lsm_l_enn_sd.RasterLayer <- function(landscape, directions = 8, verbose = TRUE) {
-    purrr::map_dfr(raster::as.list(landscape),
-                   lsm_l_enn_sd_calc,
-                   directions = directions,
-                   verbose = verbose,
-                   .id = "layer") %>%
-        dplyr::mutate(layer = as.integer(layer))
+
+    result <- lapply(X = raster::as.list(landscape),
+                     FUN = lsm_l_enn_sd_calc,
+                     directions = directions,
+                     verbose = verbose)
+
+    dplyr::mutate(dplyr::bind_rows(result, .id = "layer"),
+                  layer = as.integer(layer))
 }
 
 #' @name lsm_l_enn_sd
 #' @export
 lsm_l_enn_sd.RasterStack <- function(landscape, directions = 8, verbose = TRUE) {
-    purrr::map_dfr(raster::as.list(landscape),
-                   lsm_l_enn_sd_calc,
-                   directions = directions,
-                   verbose = verbose,
-                   .id = "layer") %>%
-        dplyr::mutate(layer = as.integer(layer))
 
+    result <- lapply(X = raster::as.list(landscape),
+                     FUN = lsm_l_enn_sd_calc,
+                     directions = directions,
+                     verbose = verbose)
+
+    dplyr::mutate(dplyr::bind_rows(result, .id = "layer"),
+                  layer = as.integer(layer))
 }
 
 #' @name lsm_l_enn_sd
 #' @export
 lsm_l_enn_sd.RasterBrick <- function(landscape, directions = 8, verbose = TRUE) {
-    purrr::map_dfr(raster::as.list(landscape),
-                   lsm_l_enn_sd_calc,
-                   directions = directions,
-                   verbose = verbose,
-                   .id = "layer") %>%
-        dplyr::mutate(layer = as.integer(layer))
 
+    result <- lapply(X = raster::as.list(landscape),
+                     FUN = lsm_l_enn_sd_calc,
+                     directions = directions,
+                     verbose = verbose)
+
+    dplyr::mutate(dplyr::bind_rows(result, .id = "layer"),
+                  layer = as.integer(layer))
+}
+
+#' @name lsm_l_enn_sd
+#' @export
+lsm_l_enn_sd.stars <- function(landscape, directions = 8, verbose = TRUE) {
+
+    landscape <- methods::as(landscape, "Raster")
+
+    result <- lapply(X = raster::as.list(landscape),
+                     FUN = lsm_l_enn_sd_calc,
+                     directions = directions,
+                     verbose = verbose)
+
+    dplyr::mutate(dplyr::bind_rows(result, .id = "layer"),
+                  layer = as.integer(layer))
 }
 
 #' @name lsm_l_enn_sd
 #' @export
 lsm_l_enn_sd.list <- function(landscape, directions = 8, verbose = TRUE) {
-    purrr::map_dfr(landscape,
-                   lsm_l_enn_sd_calc,
-                   directions = directions,
-                   verbose = verbose,
-                   .id = "layer") %>%
-        dplyr::mutate(layer = as.integer(layer))
+
+    result <- lapply(X = landscape,
+                     FUN = lsm_l_enn_sd_calc,
+                     directions = directions,
+                     verbose = verbose)
+
+    dplyr::mutate(dplyr::bind_rows(result, .id = "layer"),
+                  layer = as.integer(layer))
 }
 
 lsm_l_enn_sd_calc <- function(landscape, directions, verbose) {
 
-    enn_sd  <- landscape %>%
-        lsm_p_enn_calc(directions = directions,
-                       verbose = verbose) %>%
-        dplyr::summarize(value = stats::sd(value))
+    enn_sd <- dplyr::summarize(lsm_p_enn_calc(landscape,
+                                              directions = directions, verbose = verbose),
+                               value = stats::sd(value))
 
     tibble::tibble(
         level = "landscape",
@@ -113,5 +133,4 @@ lsm_l_enn_sd_calc <- function(landscape, directions, verbose) {
         metric = "enn_sd",
         value = as.double(enn_sd$value)
     )
-
 }
