@@ -55,51 +55,69 @@ lsm_l_gyrate_cv <- function(landscape, directions) UseMethod("lsm_l_gyrate_cv")
 #' @name lsm_l_gyrate_cv
 #' @export
 lsm_l_gyrate_cv.RasterLayer <- function(landscape, directions = 8) {
-    purrr::map_dfr(raster::as.list(landscape),
-                   lsm_l_gyrate_cv_calc,
-                   directions = directions,
-                   .id = "layer") %>%
-        dplyr::mutate(layer = as.integer(layer))
+
+    result <- lapply(X = raster::as.list(landscape),
+                     FUN = lsm_l_gyrate_cv_calc,
+                     directions = directions)
+
+    dplyr::mutate(dplyr::bind_rows(result, .id = "layer"),
+                  layer = as.integer(layer))
 }
 
 #' @name lsm_l_gyrate_cv
 #' @export
 lsm_l_gyrate_cv.RasterStack <- function(landscape, directions = 8) {
-    purrr::map_dfr(raster::as.list(landscape),
-                   lsm_l_gyrate_cv_calc,
-                   directions = directions,
-                   .id = "layer") %>%
-        dplyr::mutate(layer = as.integer(layer))
 
+    result <- lapply(X = raster::as.list(landscape),
+                     FUN = lsm_l_gyrate_cv_calc,
+                     directions = directions)
+
+    dplyr::mutate(dplyr::bind_rows(result, .id = "layer"),
+                  layer = as.integer(layer))
 }
 
 #' @name lsm_l_gyrate_cv
 #' @export
 lsm_l_gyrate_cv.RasterBrick <- function(landscape, directions = 8) {
-    purrr::map_dfr(raster::as.list(landscape),
-                   lsm_l_gyrate_cv_calc,
-                   directions = directions,
-                   .id = "layer") %>%
-        dplyr::mutate(layer = as.integer(layer))
 
+    result <- lapply(X = raster::as.list(landscape),
+                     FUN = lsm_l_gyrate_cv_calc,
+                     directions = directions)
+
+    dplyr::mutate(dplyr::bind_rows(result, .id = "layer"),
+                  layer = as.integer(layer))
+}
+
+#' @name lsm_l_gyrate_cv
+#' @export
+lsm_l_gyrate_cv.stars <- function(landscape, directions = 8) {
+
+    landscape <- methods::as(landscape, "Raster")
+
+    result <- lapply(X = raster::as.list(landscape),
+                     FUN = lsm_l_gyrate_cv_calc,
+                     directions = directions)
+
+    dplyr::mutate(dplyr::bind_rows(result, .id = "layer"),
+                  layer = as.integer(layer))
 }
 
 #' @name lsm_l_gyrate_cv
 #' @export
 lsm_l_gyrate_cv.list <- function(landscape, directions = 8) {
-    purrr::map_dfr(landscape,
-                   lsm_l_gyrate_cv_calc,
-                   directions = directions,
-                   .id = "layer") %>%
-        dplyr::mutate(layer = as.integer(layer))
 
+    result <- lapply(X = landscape,
+                     FUN = lsm_l_gyrate_cv_calc,
+                     directions = directions)
+
+    dplyr::mutate(dplyr::bind_rows(result, .id = "layer"),
+                  layer = as.integer(layer))
 }
 
 lsm_l_gyrate_cv_calc <- function(landscape, directions) {
 
-    gyrate_cv <- landscape %>%
-        lsm_p_gyrate_calc(directions = directions) %>%
-        dplyr::summarize(value = raster::cv(value))
+    gyrate_cv <- dplyr::summarize(lsm_p_gyrate_calc(landscape, directions = directions),
+                                  value = raster::cv(value))
 
     tibble::tibble(
         level = "landscape",
@@ -108,6 +126,5 @@ lsm_l_gyrate_cv_calc <- function(landscape, directions) {
         metric = "gyrate_cv",
         value = as.double(gyrate_cv$value)
     )
-
 }
 
