@@ -54,51 +54,69 @@ lsm_l_gyrate_sd <- function(landscape, directions) UseMethod("lsm_l_gyrate_sd")
 #' @name lsm_l_gyrate_sd
 #' @export
 lsm_l_gyrate_sd.RasterLayer <- function(landscape, directions = 8) {
-    purrr::map_dfr(raster::as.list(landscape),
-                   lsm_l_gyrate_sd_calc,
-                   directions = directions,
-                   .id = "layer") %>%
-        dplyr::mutate(layer = as.integer(layer))
+
+    result <- lapply(X = raster::as.list(landscape),
+                     FUN = lsm_l_gyrate_sd_calc,
+                     directions = directions)
+
+    dplyr::mutate(dplyr::bind_rows(result, .id = "layer"),
+                  layer = as.integer(layer))
 }
 
 #' @name lsm_l_gyrate_sd
 #' @export
 lsm_l_gyrate_sd.RasterStack <- function(landscape, directions = 8) {
-    purrr::map_dfr(raster::as.list(landscape),
-                   lsm_l_gyrate_sd_calc,
-                   directions = directions,
-                   .id = "layer") %>%
-        dplyr::mutate(layer = as.integer(layer))
 
+    result <- lapply(X = raster::as.list(landscape),
+                     FUN = lsm_l_gyrate_sd_calc,
+                     directions = directions)
+
+    dplyr::mutate(dplyr::bind_rows(result, .id = "layer"),
+                  layer = as.integer(layer))
 }
 
 #' @name lsm_l_gyrate_sd
 #' @export
 lsm_l_gyrate_sd.RasterBrick <- function(landscape, directions = 8) {
-    purrr::map_dfr(raster::as.list(landscape),
-                   lsm_l_gyrate_sd_calc,
-                   directions = directions,
-                   .id = "layer") %>%
-        dplyr::mutate(layer = as.integer(layer))
 
+    result <- lapply(X = raster::as.list(landscape),
+                     FUN = lsm_l_gyrate_sd_calc,
+                     directions = directions)
+
+    dplyr::mutate(dplyr::bind_rows(result, .id = "layer"),
+                  layer = as.integer(layer))
+}
+
+#' @name lsm_l_gyrate_sd
+#' @export
+lsm_l_gyrate_sd.stars <- function(landscape, directions = 8) {
+
+    landscape <- methods::as(landscape, "Raster")
+
+    result <- lapply(X = raster::as.list(landscape),
+                     FUN = lsm_l_gyrate_sd_calc,
+                     directions = directions)
+
+    dplyr::mutate(dplyr::bind_rows(result, .id = "layer"),
+                  layer = as.integer(layer))
 }
 
 #' @name lsm_l_gyrate_sd
 #' @export
 lsm_l_gyrate_sd.list <- function(landscape, directions = 8) {
-    purrr::map_dfr(landscape,
-                   lsm_l_gyrate_sd_calc,
-                   directions = directions,
-                   .id = "layer") %>%
-        dplyr::mutate(layer = as.integer(layer))
 
+    result <- lapply(X = landscape,
+                     FUN = lsm_l_gyrate_sd_calc,
+                     directions = directions)
+
+    dplyr::mutate(dplyr::bind_rows(result, .id = "layer"),
+                  layer = as.integer(layer))
 }
 
 lsm_l_gyrate_sd_calc <- function(landscape, directions) {
 
-    gyrate_sd  <- landscape %>%
-        lsm_p_gyrate_calc(directions = directions) %>%
-        dplyr::summarize(value = stats::sd(value))
+    gyrate_sd <- dplyr::summarize(lsm_p_gyrate_calc(landscape, directions = directions),
+                                  value = stats::sd(value))
 
     tibble::tibble(
         level = "landscape",
@@ -107,6 +125,5 @@ lsm_l_gyrate_sd_calc <- function(landscape, directions) {
         metric = "gyrate_sd",
         value = as.double(gyrate_sd$value)
     )
-
 }
 
