@@ -45,60 +45,83 @@
 #
 #' @export
 lsm_l_iji <- function(landscape, verbose) UseMethod("lsm_l_iji")
+
 #' @name lsm_l_iji
 #' @export
 lsm_l_iji.RasterLayer <- function(landscape, verbose = TRUE) {
-    purrr::map_dfr(raster::as.list(landscape),
-                   lsm_l_iji_calc,
-                   verbose = verbose,
-                   .id = "layer") %>%
-        dplyr::mutate(layer = as.integer(layer))
+
+    result <- lapply(X = raster::as.list(landscape),
+                     FUN = lsm_l_iji_calc,
+                     verbose = verbose)
+
+    dplyr::mutate(dplyr::bind_rows(result, .id = "layer"),
+                  layer = as.integer(layer))
 }
+
 #' @name lsm_l_iji
 #' @export
 lsm_l_iji.RasterStack <- function(landscape, verbose = TRUE) {
-    purrr::map_dfr(raster::as.list(landscape),
-                   lsm_l_iji_calc,
-                   verbose = verbose,
-                   .id = "layer") %>%
-        dplyr::mutate(layer = as.integer(layer))
+
+    result <- lapply(X = raster::as.list(landscape),
+                     FUN = lsm_l_iji_calc,
+                     verbose = verbose)
+
+    dplyr::mutate(dplyr::bind_rows(result, .id = "layer"),
+                  layer = as.integer(layer))
 }
+
 #' @name lsm_l_iji
 #' @export
 lsm_l_iji.RasterBrick <- function(landscape, verbose = TRUE) {
-    purrr::map_dfr(raster::as.list(landscape),
-                   lsm_l_iji_calc,
-                   verbose = verbose,
-                   .id = "layer") %>%
-        dplyr::mutate(layer = as.integer(layer))
+
+    result <- lapply(X = raster::as.list(landscape),
+                     FUN = lsm_l_iji_calc,
+                     verbose = verbose)
+
+    dplyr::mutate(dplyr::bind_rows(result, .id = "layer"),
+                  layer = as.integer(layer))
 }
+
+#' @name lsm_l_iji
+#' @export
+lsm_l_iji.stars <- function(landscape, verbose = TRUE) {
+
+    landscape <- methods::as(landscape, "Raster")
+
+    result <- lapply(X = raster::as.list(landscape),
+                     FUN = lsm_l_iji_calc,
+                     verbose = verbose)
+
+    dplyr::mutate(dplyr::bind_rows(result, .id = "layer"),
+                  layer = as.integer(layer))
+}
+
 #' @name lsm_l_iji
 #' @export
 lsm_l_iji.list <- function(landscape, verbose = TRUE) {
-    purrr::map_dfr(raster::as.list(landscape),
-                   lsm_l_iji_calc,
-                   verbose = verbose,
-                   .id = "layer") %>%
-        dplyr::mutate(layer = as.integer(layer))
+
+    result <- lapply(X = landscape,
+                     FUN = lsm_l_iji_calc,
+                     verbose = verbose)
+
+    dplyr::mutate(dplyr::bind_rows(result, .id = "layer"),
+                  layer = as.integer(layer))
 }
 
 lsm_l_iji_calc <- function(landscape, verbose) {
 
-    adjacencies <-
-        rcpp_get_coocurrence_matrix(raster::as.matrix(landscape),
-                                    as.matrix(4))
+    adjacencies <- rcpp_get_coocurrence_matrix(raster::as.matrix(landscape),
+                                               as.matrix(4))
 
     if (ncol(adjacencies) < 3) {
 
         if(isTRUE(verbose)) {
-            warning("Number of classes must be >= 3,
-                    IJI = NA.",
-                    call. = FALSE)
+            warning("Number of classes must be >= 3, IJI = NA.", call. = FALSE)
         }
 
         tibble::tibble(
-            level = "class",
-            class = as.integer(raster::unique(landscape)),
+            level = "landscape",
+            class = as.integer(NA),
             id = as.integer(NA),
             metric = "iji",
             value = as.double(NA)
@@ -110,20 +133,13 @@ lsm_l_iji_calc <- function(landscape, verbose) {
 
         e_total <- sum(adjacencies[lower.tri(adjacencies)])
 
-        edge_ratio <-
-            (adjacencies / e_total) * log(adjacencies / e_total)
+        edge_ratio <- (adjacencies / e_total) * log(adjacencies / e_total)
 
         edge_ratio <- edge_ratio[lower.tri(edge_ratio)]
 
         landscape_sum <- -sum(edge_ratio, na.rm = TRUE)
 
-        iji <-
-            (landscape_sum /
-                 log(0.5  * (ncol(
-                     adjacencies
-                 ) * (
-                     ncol(adjacencies)  - 1
-                 )))) * 100
+        iji <- (landscape_sum / log(0.5  * (ncol(adjacencies) * (ncol(adjacencies)  - 1)))) * 100
 
         tibble::tibble(
             level = "landscape",
