@@ -45,13 +45,15 @@ lsm_l_mutinf.RasterLayer <- function(landscape,
                                      neighbourhood = 4,
                                      ordered = TRUE,
                                      base = "log2") {
-    purrr::map_dfr(raster::as.list(landscape),
-                   lsm_l_mutinf_calc,
-                   neighbourhood = neighbourhood,
-                   ordered = ordered,
-                   base = base,
-                   .id = "layer") %>%
-        dplyr::mutate(layer = as.integer(layer))
+
+    result <- lapply(X = raster::as.list(landscape),
+                     FUN = lsm_l_mutinf_calc,
+                     neighbourhood = neighbourhood,
+                     ordered = ordered,
+                     base = base)
+
+    dplyr::mutate(dplyr::bind_rows(result, .id = "layer"),
+                  layer = as.integer(layer))
 }
 
 #' @name lsm_l_mutinf
@@ -60,14 +62,15 @@ lsm_l_mutinf.RasterStack <- function(landscape,
                                      neighbourhood = 4,
                                      ordered = TRUE,
                                      base = "log2") {
-    purrr::map_dfr(raster::as.list(landscape),
-                   lsm_l_mutinf_calc,
-                   neighbourhood = neighbourhood,
-                   ordered = ordered,
-                   base = base,
-                   .id = "layer") %>%
-        dplyr::mutate(layer = as.integer(layer))
 
+    result <- lapply(X = raster::as.list(landscape),
+                     FUN = lsm_l_mutinf_calc,
+                     neighbourhood = neighbourhood,
+                     ordered = ordered,
+                     base = base)
+
+    dplyr::mutate(dplyr::bind_rows(result, .id = "layer"),
+                  layer = as.integer(layer))
 }
 
 #' @name lsm_l_mutinf
@@ -76,14 +79,34 @@ lsm_l_mutinf.RasterBrick <- function(landscape,
                                      neighbourhood = 4,
                                      ordered = TRUE,
                                      base = "log2") {
-    purrr::map_dfr(raster::as.list(landscape),
-                   lsm_l_mutinf_calc,
-                   neighbourhood = neighbourhood,
-                   ordered = ordered,
-                   base = base,
-                   .id = "layer") %>%
-        dplyr::mutate(layer = as.integer(layer))
 
+    result <- lapply(X = raster::as.list(landscape),
+                     FUN = lsm_l_mutinf_calc,
+                     neighbourhood = neighbourhood,
+                     ordered = ordered,
+                     base = base)
+
+    dplyr::mutate(dplyr::bind_rows(result, .id = "layer"),
+                  layer = as.integer(layer))
+}
+
+#' @name lsm_l_mutinf
+#' @export
+lsm_l_mutinf.stars <- function(landscape,
+                                neighbourhood = 4,
+                                ordered = TRUE,
+                                base = "log2") {
+
+    landscape <- methods::as(landscape, "Raster")
+
+    result <- lapply(X = raster::as.list(landscape),
+                     FUN = lsm_l_mutinf_calc,
+                     neighbourhood = neighbourhood,
+                     ordered = ordered,
+                     base = base)
+
+    dplyr::mutate(dplyr::bind_rows(result, .id = "layer"),
+                  layer = as.integer(layer))
 }
 
 #' @name lsm_l_mutinf
@@ -92,13 +115,15 @@ lsm_l_mutinf.list <- function(landscape,
                               neighbourhood = 4,
                               ordered = TRUE,
                               base = "log2") {
-    purrr::map_dfr(landscape,
-                   lsm_l_mutinf_calc,
-                   neighbourhood = neighbourhood,
-                   ordered = ordered,
-                   base = base,
-                   .id = "layer") %>%
-        dplyr::mutate(layer = as.integer(layer))
+
+    result <- lapply(X = landscape,
+                     FUN = lsm_l_mutinf_calc,
+                     neighbourhood = neighbourhood,
+                     ordered = ordered,
+                     base = base)
+
+    dplyr::mutate(dplyr::bind_rows(result, .id = "layer"),
+                  layer = as.integer(layer))
 }
 
 lsm_l_mutinf_calc <- function(landscape, neighbourhood, ordered, base){
@@ -108,6 +133,7 @@ lsm_l_mutinf_calc <- function(landscape, neighbourhood, ordered, base){
     coh <- rcpp_get_coocurrence_vector(landscape_matrix,
                                        directions = as.matrix(neighbourhood),
                                        ordered = ordered)
+
     comp <- rcpp_get_entropy(cmh, base)
     cplx <- rcpp_get_entropy(coh, base)
     conf <- cplx - comp
