@@ -48,41 +48,63 @@ lsm_l_split <- function(landscape, directions) UseMethod("lsm_l_split")
 #' @name lsm_l_split
 #' @export
 lsm_l_split.RasterLayer <- function(landscape, directions = 8) {
-    purrr::map_dfr(raster::as.list(landscape),
-                   lsm_l_split_calc,
-                   directions = directions,
-                   .id = "layer") %>%
-        dplyr::mutate(layer = as.integer(layer))
+
+    result <- lapply(X = raster::as.list(landscape),
+                     FUN = lsm_l_split_calc,
+                     directions = directions)
+
+    dplyr::mutate(dplyr::bind_rows(result, .id = "layer"),
+                  layer = as.integer(layer))
 }
 
 #' @name lsm_l_split
 #' @export
 lsm_l_split.RasterStack <- function(landscape, directions = 8) {
-    purrr::map_dfr(raster::as.list(landscape),
-                   lsm_l_split_calc,
-                   directions = directions,
-                   .id = "layer") %>%
-        dplyr::mutate(layer = as.integer(layer))
+
+    result <- lapply(X = raster::as.list(landscape),
+                     FUN = lsm_l_split_calc,
+                     directions = directions)
+
+    dplyr::mutate(dplyr::bind_rows(result, .id = "layer"),
+                  layer = as.integer(layer))
 }
 
 #' @name lsm_l_split
 #' @export
 lsm_l_split.RasterBrick <- function(landscape, directions = 8) {
-    purrr::map_dfr(raster::as.list(landscape),
-                   lsm_l_split_calc,
-                   directions = directions,
-                   .id = "layer") %>%
-        dplyr::mutate(layer = as.integer(layer))
+
+    result <- lapply(X = raster::as.list(landscape),
+                     FUN = lsm_l_split_calc,
+                     directions = directions)
+
+    dplyr::mutate(dplyr::bind_rows(result, .id = "layer"),
+                  layer = as.integer(layer))
+}
+
+#' @name lsm_l_split
+#' @export
+lsm_l_split.stars <- function(landscape, directions = 8) {
+
+    landscape <- methods::as(landscape, "Raster")
+
+    result <- lapply(X = raster::as.list(landscape),
+                     FUN = lsm_l_split_calc,
+                     directions = directions)
+
+    dplyr::mutate(dplyr::bind_rows(result, .id = "layer"),
+                  layer = as.integer(layer))
 }
 
 #' @name lsm_l_split
 #' @export
 lsm_l_split.list <- function(landscape, directions = 8) {
-    purrr::map_dfr(landscape,
-                   lsm_l_split_calc,
-                   directions = directions,
-                   .id = "layer") %>%
-        dplyr::mutate(layer = as.integer(layer))
+
+    result <- lapply(X = landscape,
+                     FUN = lsm_l_split_calc,
+                     directions = directions)
+
+    dplyr::mutate(dplyr::bind_rows(result, .id = "layer"),
+                  layer = as.integer(layer))
 }
 
 lsm_l_split_calc <- function(landscape, directions) {
@@ -91,10 +113,10 @@ lsm_l_split_calc <- function(landscape, directions) {
 
     area_patch <- lsm_p_area_calc(landscape, directions = directions)
 
-    split <- area_patch %>%
-        dplyr::mutate(value = value ^ 2) %>%
-        dplyr::summarise(value = sum(value)) %>%
-        dplyr::mutate(value = (area_landscape$value ^ 2) / value)
+    split <- dplyr::mutate(area_patch, value = value ^ 2)
+
+    split <- dplyr::mutate(dplyr::summarise(split, value = sum(value)),
+                           value = (area_landscape$value ^ 2) / value)
 
     tibble::tibble(
         level = "landscape",
