@@ -50,66 +50,85 @@ lsm_p_area <- function(landscape, directions) UseMethod("lsm_p_area")
 #' @name lsm_p_area
 #' @export
 lsm_p_area.RasterLayer <- function(landscape, directions = 8) {
-    purrr::map_dfr(raster::as.list(landscape),
-                   lsm_p_area_calc,
-                   directions = directions,
-                   .id = "layer") %>%
-        dplyr::mutate(layer = as.integer(layer))
+
+    result <- lapply(X = raster::as.list(landscape),
+                     FUN = lsm_p_area_calc,
+                     directions = directions)
+
+    dplyr::mutate(dplyr::bind_rows(result, .id = "layer"),
+                  layer = as.integer(layer))
 }
 
 #' @name lsm_p_area
 #' @export
 lsm_p_area.RasterStack <- function(landscape, directions = 8) {
-    purrr::map_dfr(raster::as.list(landscape),
-                   lsm_p_area_calc,
-                   directions = directions,
-                   .id = "layer") %>%
-        dplyr::mutate(layer = as.integer(layer))
 
+    result <- lapply(X = raster::as.list(landscape),
+                     FUN = lsm_p_area_calc,
+                     directions = directions)
+
+    dplyr::mutate(dplyr::bind_rows(result, .id = "layer"),
+                  layer = as.integer(layer))
 }
 
 #' @name lsm_p_area
 #' @export
 lsm_p_area.RasterBrick <- function(landscape, directions = 8) {
-    purrr::map_dfr(raster::as.list(landscape),
-                   lsm_p_area_calc,
-                   directions = directions,
-                   .id = "layer") %>%
-        dplyr::mutate(layer = as.integer(layer))
 
+    result <- lapply(X = raster::as.list(landscape),
+                     FUN = lsm_p_area_calc,
+                     directions = directions)
+
+    dplyr::mutate(dplyr::bind_rows(result, .id = "layer"),
+                  layer = as.integer(layer))
+}
+
+#' @name lsm_p_area
+#' @export
+lsm_p_area.stars <- function(landscape, directions = 8) {
+
+    landscape <- methods::as(landscape, "Raster")
+
+    result <- lapply(X = raster::as.list(landscape),
+                     FUN = lsm_p_area_calc,
+                     directions = directions)
+
+    dplyr::mutate(dplyr::bind_rows(result, .id = "layer"),
+                  layer = as.integer(layer))
 }
 
 #' @name lsm_p_area
 #' @export
 lsm_p_area.list <- function(landscape, directions = 8) {
-    purrr::map_dfr(landscape,
-                   lsm_p_area_calc,
-                   directions = directions,
-                   .id = "layer") %>%
-        dplyr::mutate(layer = as.integer(layer))
 
+    result <- lapply(X = landscape,
+                     FUN = lsm_p_area_calc,
+                     directions = directions)
+
+    dplyr::mutate(dplyr::bind_rows(result, .id = "layer"),
+                  layer = as.integer(layer))
 }
 
 lsm_p_area_calc <- function(landscape, directions){
 
     landscape_labeled <- get_patches(landscape, directions = directions)
 
-    area_patch <- purrr::map_dfr(landscape_labeled, function(patches_class){
+    area_patch_list <- lapply(landscape_labeled, function(patches_class){
+
+        class <- sub("Class_", "", names(patches_class))
 
         area_patch_ij <- rcpp_get_composition_vector(
             x = raster::as.matrix(patches_class)) *
             prod(raster::res(patches_class)) / 10000
 
-        class <- patches_class %>%
-            names() %>%
-            sub("Class_", "", .)
-
         tibble::tibble(
             class = as.integer(class),
             value = area_patch_ij
         )
     })
 
+    area_patch <- dplyr::bind_rows(area_patch_list)
+
     tibble::tibble(
         level = "patch",
         class = as.integer(area_patch$class),
