@@ -51,76 +51,96 @@ lsm_p_gyrate <- function(landscape, directions) UseMethod("lsm_p_gyrate")
 #' @name lsm_p_gyrate
 #' @export
 lsm_p_gyrate.RasterLayer <- function(landscape, directions = 8) {
-    purrr::map_dfr(raster::as.list(landscape),
-                   lsm_p_gyrate_calc, directions = directions,
-                   .id = "layer") %>%
-        dplyr::mutate(layer = as.integer(layer))
+
+    result <- lapply(X = raster::as.list(landscape),
+                     FUN = lsm_p_gyrate_calc,
+                     directions = directions)
+
+    dplyr::mutate(dplyr::bind_rows(result, .id = "layer"),
+                  layer = as.integer(layer))
 }
 
 #' @name lsm_p_gyrate
 #' @export
 lsm_p_gyrate.RasterStack <- function(landscape, directions = 8) {
-    purrr::map_dfr(raster::as.list(landscape),
-                   lsm_p_gyrate_calc,
-                   directions = directions,
-                   .id = "layer") %>%
-        dplyr::mutate(layer = as.integer(layer))
 
+    result <- lapply(X = raster::as.list(landscape),
+                     FUN = lsm_p_gyrate_calc,
+                     directions = directions)
+
+    dplyr::mutate(dplyr::bind_rows(result, .id = "layer"),
+                  layer = as.integer(layer))
 }
 
 #' @name lsm_p_gyrate
 #' @export
 lsm_p_gyrate.RasterBrick <- function(landscape, directions = 8) {
-    purrr::map_dfr(raster::as.list(landscape),
-                   lsm_p_gyrate_calc,
-                   directions = directions,
-                   .id = "layer") %>%
-        dplyr::mutate(layer = as.integer(layer))
 
+    result <- lapply(X = raster::as.list(landscape),
+                     FUN = lsm_p_gyrate_calc,
+                     directions = directions)
+
+    dplyr::mutate(dplyr::bind_rows(result, .id = "layer"),
+                  layer = as.integer(layer))
+}
+
+#' @name lsm_p_gyrate
+#' @export
+lsm_p_gyrate.stars <- function(landscape, directions = 8) {
+
+    landscape <- methods::as(landscape, "Raster")
+
+
+    result <- lapply(X = raster::as.list(landscape),
+                     FUN = lsm_p_gyrate_calc,
+                     directions = directions)
+
+    dplyr::mutate(dplyr::bind_rows(result, .id = "layer"),
+                  layer = as.integer(layer))
 }
 
 #' @name lsm_p_gyrate
 #' @export
 lsm_p_gyrate.list <- function(landscape, directions = 8) {
-    purrr::map_dfr(landscape, lsm_p_gyrate_calc,
-                   directions = directions,
-                   .id = "layer") %>%
-        dplyr::mutate(layer = as.integer(layer))
 
+    result <- lapply(X = landscape,
+                     FUN = lsm_p_gyrate_calc,
+                     directions = directions)
+
+    dplyr::mutate(dplyr::bind_rows(result, .id = "layer"),
+                  layer = as.integer(layer))
 }
 
 lsm_p_gyrate_calc <- function(landscape, directions) {
 
     landscape_labeled <- get_patches(landscape, directions = directions)
 
-    gyrate <- purrr::map_dfr(landscape_labeled, function(patches_class) {
+    gyrate <- lapply(landscape_labeled, function(patches_class) {
 
-        class <- patches_class %>%
-            names() %>%
-            sub("Class_", "", .)
+        class <- sub("Class_", "", names(patches_class))
 
-        points_class <- patches_class %>%
-            raster::rasterToPoints() %>%
-            tibble::as.tibble() %>%
-            purrr::set_names(c("x", "y", "id"))
+        points_class <- tibble::as.tibble(raster::rasterToPoints(patches_class))
+        names(points_class) <- c("x", "y", "id")
 
-        centroid <- points_class %>%
-            dplyr::group_by(id) %>%
-            dplyr::summarise(x_centroid = mean(x),
-                             y_centroid = mean(y))
+        centroid <- dplyr::summarise(dplyr::group_by(points_class, id),
+                                     x_centroid = mean(x),
+                                     y_centroid = mean(y))
 
         full_data <- dplyr::left_join(x = points_class, y = centroid, by = "id")
 
-        gyrate_class <-  dplyr::mutate(full_data, dist =
-                                           sqrt((x - x_centroid) ^ 2 +
-                                                    (y - y_centroid) ^ 2)) %>%
-            dplyr::group_by(id) %>%
-            dplyr::summarise(value = mean(dist))
+        gyrate_class <- dplyr::summarise(
+            dplyr::group_by(
+                dplyr::mutate(full_data, dist = sqrt((x - x_centroid) ^ 2 + (y - y_centroid) ^ 2)),
+                id),
+            value = mean(dist)
+            )
 
         tibble::tibble(class = as.integer(class),
                        value = as.double(gyrate_class$value))
     })
 
+    gyrate <- dplyr::bind_rows(gyrate)
+
     tibble::tibble(level = "patch",
                    class = as.integer(gyrate$class),
                    id = as.integer(seq_len(nrow(gyrate))),
