@@ -13,7 +13,7 @@
 #' @return ggplot
 #'
 #' @examples
-#' metrics <- calculate_metrics(landscape, what = c("patch", "class"))
+#' metrics <- calculate_lsm(landscape, what = c("patch", "class"))
 #' show_correlation(metrics, method = "pearson")
 #'
 #' @aliases show_correlation
@@ -194,9 +194,12 @@ show_correlation <-
                     ifnotfound = list(NA)
                 )
 
-            corrs_df <- do.call(rbind, corrs_list) %>%
-                dplyr::group_by(id) %>%
-                dplyr::filter(!all(is.na(value)))
+            corrs_df <- dplyr::filter(
+                dplyr::group_by(
+                    do.call(rbind, corrs_list),
+                    id),
+                !all(is.na(value))
+                )
 
             corrs_df$id <-
                 factor(corrs_df$id, levels = unique(corrs_df$id))
@@ -233,6 +236,6 @@ show_correlation <-
 
         }
 
-        return(plot_corrs)
+        suppressWarnings(return(plot_corrs))
 
 }
